#ifndef TPG300_H
#define TPG300_H

#include <QWidget>
#include <QtGui>

#include <qextserialport.h> // gestion des connexions RS232

#include "ui_tpg300.h" // interface graphique
#include "fenetre_rs232.h" // fenetre de configuration RS232
#include "fenetre_parametres.h" // fenetre de configuration de la mesure
#include "threadtpg300.h" // gestion du thread pour les mesures

class TPG300 : public QMainWindow
{
  Q_OBJECT

// variables et fonctions
public:
  TPG300(QWidget *parent = 0); // constructeur

  Ui::TPG300 ui; // interface graphique principale
  RS232 fenetre_rs232; // fenetre pour configurer la connexion RS232
  PARAMETRES fenetre_parametres; // fenetre pour configurer la mesure

  QextSerialPort *port; // sert a communiquer par le port serie

  RenderThread thread; // le thread qui lit les donnees de mesure


  void affichage_moniteur(QString la_commande); // permet d'afficher sur le moniteur

  // envoi et reception
  int send_rs232(QString la_commande); // envoyer vers l'appareil
  QString receive_rs232(void); // recevoir une ligne de l'appareil
  void mesure(void); // On realise une mesure des pressions

  // les fonctions de dialogue
  QString programmnumber(void); // TPG300 Programm number PNR
  QString codelock(void); // TPG300 Code lock
  QString errorstatus(void); // TPG300 Error Status
  QString displayunit(void); // TPG300 Display Unit
  QString underrangecontrol(void); // TPG300 underrange control
  QString setpoint(QString identifiant); // TPG300 Set Point
  QString setpointswitching(void); // TPG300 Switching function status
  QString sensoronoff(void); // TPG300 Sensor On/Off
  QString filtertime(void); // TPG300 Filter Time
  QString slotids(void); // TPG300 Slot ID's
  QString getpress(QString identifiant); // TPG300 Get Press

  QString pressuremeasurement(QString identifiant); // TPG261 Pressure Measurement PRx
  QString gaugeidentification(void); // TPG261 Gauge identification TID
  QString errorstatus2(void); // TPG261 Error Status ERR
  QString pressureunit(void); // TPG261 Pressure Unit UNI
  QString sensoronoff2(void); // TPG261 Sensor on/off SEN // A finir




  QString nom_file; // nom du fichier de stockage des donnees
  QDateTime date_init; // heure de debut
  int nb_cycles; // nombre de cycles de mesures

// les elements du UI
public slots:
  void on_pushButton_1_1_clicked();  // configuration RS232
  void on_pushButton_1_2_clicked();  // configuration paramtres
  void on_pushButton_1_3_clicked();  // connexion a l'appareil

};

#endif
